Package: handlr
Title: Convert Among Citation Formats
Description: Converts among many citation formats, including 'BibTeX',
    'Citeproc', 'Codemeta', 'RDF XML', 'RIS', 'Schema.org', and
    'Citation File Format'. A low level 'R6' class is provided, as well
    as stand-alone functions for each citation format for both read
    and write.
Version: 0.3.0
License: MIT + file LICENSE
Authors@R: c(
    person("Scott", "Chamberlain", role = c("aut", "cre"),
    email = "sckott@protonmail.com",
    comment = c(ORCID = "0000-0003-1444-9135"))
    )
URL: https://github.com/ropensci/handlr (devel),
        https://docs.ropensci.org/handlr/ (docs)
BugReports: https://github.com/ropensci/handlr/issues
Roxygen: list(markdown = TRUE)
Encoding: UTF-8
Language: en-US
Imports: jsonlite, crul, xml2, urltools, mime, yaml
Suggests: testthat, data.table, bibtex
RoxygenNote: 7.1.1
X-schema.org-applicationCategory: Metadata
X-schema.org-keywords: doi, metadata, citation, bibtex, Crossref,
        Crosscite, Codemeta, RIS, Citeproc, RDF, XML, JSON
X-schema.org-isPartOf: https://ropensci.org
Author: Scott Chamberlain [aut, cre] (<https://orcid.org/0000-0003-1444-9135>)
Maintainer: Scott Chamberlain <sckott@protonmail.com>
Built: R 4.4.0; ; 2024-05-05 21:00:38 UTC; unix
