# Generated by roxygen2: do not edit by hand

S3method(c,handl)
S3method(print,handl)
export(HandlrClient)
export(bibtex_reader)
export(bibtex_writer)
export(cff_reader)
export(cff_writer)
export(citeproc_reader)
export(citeproc_writer)
export(codemeta_reader)
export(codemeta_writer)
export(handl_to_df)
export(rdf_xml_writer)
export(ris_reader)
export(ris_writer)
export(schema_org_writer)
importFrom(crul,HttpClient)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(mime,guess_type)
importFrom(urltools,url_encode)
importFrom(urltools,url_parse)
importFrom(xml2,read_xml)
